@@ -24,6 +24,24 @@ class pySwitch:
         # it is expression of ternary operator
         return (True if val == attr else False)
 
+    @property
+    def name(self):
+        """Name of the device."""
+        return self.__device.title
+
+    @property
+    def unique_id(self):
+        """Unique id of the device."""
+        return self.__device.id
+
+    def turn_off(self):
+        """Turn the switch off."""
+        self.__device.set_value(0)
+
+    def turn_on(self):
+        """Turn the switch on."""
+        self.__device.set_value(1)
+
     def __repr__(self):
         """Object representation."""
         state = "on" if self.state else "off"
